#!/usr/bin/env bash

shopt -s dotglob
[ "${DEBUG:-}" == 'true' ] && set -x

set_default ()
{
    server_hostname='GameAP Rust'
    server_maxplayers='32'
    server_level='Procedural Map'
    server_ip='0.0.0.0'
    server_port='28015'
    server_rcon_ip='0.0.0.0'
    server_rcon_port='28016'
    server_rcon_password='secretpass'
    server_saveinterval='300'
    server_worldsize='4000'
    server_seed='1234'
}

parse_options ()
{
    for i in "$@"
    do
        case $i in
            -h|--help)
                show_logo
                show_help
                exit 0
            ;;
            --hostname=*)
                server_hostname="${i#*=}"
                shift
            ;;
            --maxplayers=*)
                server_maxplayers="${i#*=}"
                shift
            ;;
            --level=*|--world=*)
                server_level="${i#*=}"
                shift
            ;;
            --levelsize=*|--worldsize=*)
                server_worldsize="${i#*=}"
                shift
            ;;
            --ip=*)
                server_ip="${i#*=}"
                server_rcon_ip="${i#*=}"
                shift
            ;;
            --port=*)
                server_port="${i#*=}"
                shift
            ;;
            --rcon-port=*)
                server_rcon_port="${i#*=}"
                shift
            ;;
            --rcon-password=*)
                server_rcon_password="${i#*=}"
                shift
            ;;
            --saveinterval=*)
                server_saveinterval="${i#*=}"
                shift
            ;;
            --seed=*)
                server_seed="${i#*=}"
                shift
        esac
    done
}

show_help ()
{
    echo
    echo 'Usage:	./run.sh COMMAND [OPTIONS]'
    echo
    echo 'Options:'
    echo '      --hostname=             Server hostname'
    echo '      --maxplayers=           Maximum players'
    echo '      --level=                Server level'
    echo '      --ip=                   Server ip'
    echo '      --port=                 Server port'
    echo '      --rcon-port=            Server rcon port'
    echo '      --rcon-password=        Server rcon password'
    echo '      --worldsize=            Server world size'
    echo '      --saveinterval=         Server save interval'
    echo '      --seed=                 Server seed'
    echo
    echo 'Examples:'
    echo '      ./run.sh --hostname="My Super Server" --maxplayers=50 --level="Procedural Map" --rcon-password="superpassword" --seed=1234'
    echo
}

show_logo ()
{
    echo
    echo '
                  ###           ####
               #######################
               #######################
              #######````````````#######
            ######   ############   ######
          #####  ####             ##  ########
      ########  ###               ####  ########
     ######## ###                 ###### ########
      ###### ####     ################### ######
       ####  ####     ################### #####
       #### #####     ###           #####  ####
       #### #####     ###           #####  ####
       ####  ####     #########     ##### #####
      ###### ####     #########     ##### ######
     ######## ###       ######      #### ########
      ########  ##                 ###  ########
       ########   ###            ###   #####
            #####    ############   ######
              #######````````````#######
                #######################
                #######################
                 #####          ####'
    echo
    echo '             GameAP Rust Server Runner'
    echo
    echo '----------------------------------------------------'
    echo
}

run ()
{
    export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:`dirname $0`/RustDedicated_Data/Plugins:`dirname $0`/RustDedicated_Data/Plugins/x86_64

    ./RustDedicated \
        -batchmode \
        +server.hostname "${server_hostname:-GameAP Rust}" \
        +server.maxplayers ${server_maxplayers:-32} \
        +server.level "${server_level:-Procedural Map}" \
        +server.ip ${server_ip:-0.0.0.0} \
        +server.port ${server_port:-28015} \
        +rcon.ip ${server_rcon_ip:-0.0.0.0} \
        +rcon.port ${server_rcon_port:-28016} \
        +rcon.password ${server_rcon_password:-secretpassword} \
        +server.saveinterval ${server_saveinterval:-300} \
        +server.worldsize ${server_worldsize:-4000} \
        +server.seed ${server_seed:-1234} \
        +server.secure true
}

main ()
{
    show_logo
    run
}

set_default
parse_options "$@"
main
